# FailureReasonDetailsResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**failure_reason** | [**FailureReasonResponse**](FailureReasonResponse.md) |  | 
**failure_reason_string** | **str** |  | 
**sites** | [**list[SiteDetails]**](SiteDetails.md) |  | [optional] 
**details** | **str** |  | 
**site_name** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

